Module alphas

Module alphas 

This module provides implementations for calculating the strong coupling constant.

It includes support for different calculation methods, such as analytic formulas and interpolation from tabulated values, mirroring the functionality available in LHAPDF.

Structs

AlphaSAnalytic
Strong coupling calculator using the analytic formulas.
AlphaSInterpol
Strong coupling calculator using interpolation.

Enums

AlphaS
Enum representing the different methods for alpha_s calculation.
Error
Errors that can occur during the analytical computations of alpha_s.