pub struct PySubGrid { /* private fields */ }Expand description
Python wrapper for the SubGrid struct.
Implementations
Sourceimpl PySubGrid
impl PySubGrid
Sourcepub fn new(
xs: Vec<f64>,
q2s: Vec<f64>,
kts: Vec<f64>,
xsis: Vec<f64>,
deltas: Vec<f64>,
nucleons: Vec<f64>,
alphas: Vec<f64>,
grid: PyReadonlyArrayDyn<'_, f64>,
) -> PyResult<Self>
pub fn new( xs: Vec<f64>, q2s: Vec<f64>, kts: Vec<f64>, xsis: Vec<f64>, deltas: Vec<f64>, nucleons: Vec<f64>, alphas: Vec<f64>, grid: PyReadonlyArrayDyn<'_, f64>, ) -> PyResult<Self>
Constructs a new SubGrid instance from the provided axes and grid data.
Parameters
xs: The x-axis values.q2s: The Q^2-axis values.kts: The kT-axis values.xsis: The Skeweness\xi.deltas: The total momentum fraction\Delta.nucleons: The nucleon number axis values.alphas: Thealpha_saxis values.grid: The 6D grid data as aNumPyarray.
Returns
Returns a new PySubGrid instance.
Panics
Panics if any of the input vectors are empty.
Errors
Returns a PyErr if the grid cannot be constructed from the input data.
Sourcepub const fn alphas_range(&self) -> (f64, f64)
pub const fn alphas_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the alpha_s axis.
Sourcepub const fn x_range(&self) -> (f64, f64)
pub const fn x_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the momentum fraction x.
Sourcepub const fn q2_range(&self) -> (f64, f64)
pub const fn q2_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the momentum scale Q^2.
Sourcepub const fn xi_range(&self) -> (f64, f64)
pub const fn xi_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the skeweness xi.
Sourcepub const fn delta_range(&self) -> (f64, f64)
pub const fn delta_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the total momentum fraction delta.
Sourcepub const fn nucleons_range(&self) -> (f64, f64)
pub const fn nucleons_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the Nucleon number A.
Sourcepub const fn kt_range(&self) -> (f64, f64)
pub const fn kt_range(&self) -> (f64, f64)
Returns the minimum and maximum values of the transverse momentum kT.
Sourcepub fn grid_shape(&self) -> Vec<usize>
pub fn grid_shape(&self) -> Vec<usize>