register

Function register 

pub fn register(parent_module: &Bound<'_, PyModule>) -> PyResult<()>
Registers the metadata submodule with the parent Python module.

Parameters

parent_module : pyo3.Bound[pyo3.types.PyModule] The parent Python module to which the metadata submodule will be added.

Returns

pyo3.PyResult<()> Ok(()) if the registration is successful, or an error if the submodule cannot be created or added.

Errors

Raises an error if the (sub)module is not found or cannot be registered.