PyMetaData

Struct PyMetaData 

pub struct PyMetaData { /* private fields */ }
Grid metadata.

Implementations

Source

impl PyMetaData

pub fn new( set_desc: String, set_index: u32, num_members: u32, x_min: f64, x_max: f64, q_min: f64, q_max: f64, xsi_min: f64, xsi_max: f64, delta_min: f64, delta_max: f64, flavors: Vec<i32>, format: String, alphas_q_values: Vec<f64>, alphas_vals: Vec<f64>, polarised: bool, set_type: PySetType, interpolator_type: PyInterpolatorType, error_type: String, hadron_pid: i32, phys_params: PyPhysicsParameters, ) -> Self

Constructor for PyMetaData.

pub fn to_dict(&self, py: Python<'_>) -> PyResult<Py<PyAny>>

Convert to Python dictionary

Errors

Raises an erro if the values are not Python compatible.

pub fn has_key(&self, key: &str) -> bool

Return True if the given LHAPDF-canonical key is present in the metadata.

pub fn get_entry(&self, key: &str) -> PyResult<String>

Return the string value for an LHAPDF-canonical metadata key.

Errors

Raises KeyError if the key is not present.

pub fn keys(&self) -> Vec<String>

Return a sorted list of all available LHAPDF-canonical metadata keys.

pub const fn set_desc(&self) -> &String

The description of the set.

pub const fn set_index(&self) -> u32

The index of the grid.

pub const fn number_sets(&self) -> u32

The number of sets in the grid.

pub const fn x_min(&self) -> f64

The minimum value of x in the grid.

pub const fn x_max(&self) -> f64

The maximum value of x in the grid.

pub const fn q_min(&self) -> f64

The minimum value of q in the grid.

pub const fn q_max(&self) -> f64

The maximum value of q in the grid.

pub const fn xi_min(&self) -> f64

The minimum value of xi in the grid.

pub const fn xi_max(&self) -> f64

The maximum value of xi in the grid.

pub const fn delta_min(&self) -> f64

The minimum value of delta in the grid.

pub const fn delta_max(&self) -> f64

The maximum value of delta in the grid.

pub const fn pids(&self) -> &Vec<i32>

The particle IDs of the grid.

pub const fn format(&self) -> &String

The format of the grid.

pub const fn alphas_q(&self) -> &Vec<f64>

The values of q for the running of the strong coupling constant.

pub const fn alphas_values(&self) -> &Vec<f64>

The values of the running of the strong coupling constant.

pub const fn is_polarised(&self) -> bool

Whether the grid is polarised.

pub fn set_type(&self) -> PySetType

The type of the set.

pub fn interpolator_type(&self) -> PyInterpolatorType

The interpolation method used for the grid.

pub const fn error_type(&self) -> &String

The type of error.

pub const fn hadron_pid(&self) -> i32

The hadron PID.