pub struct PyMetaData { /* private fields */ }Expand description
Grid metadata.
Implementations
Sourceimpl PyMetaData
impl PyMetaData
Sourcepub fn new(
set_desc: String,
set_index: u32,
num_members: u32,
x_min: f64,
x_max: f64,
q_min: f64,
q_max: f64,
xsi_min: f64,
xsi_max: f64,
delta_min: f64,
delta_max: f64,
flavors: Vec<i32>,
format: String,
alphas_q_values: Vec<f64>,
alphas_vals: Vec<f64>,
polarised: bool,
set_type: PySetType,
interpolator_type: PyInterpolatorType,
error_type: String,
hadron_pid: i32,
phys_params: PyPhysicsParameters,
) -> Self
pub fn new( set_desc: String, set_index: u32, num_members: u32, x_min: f64, x_max: f64, q_min: f64, q_max: f64, xsi_min: f64, xsi_max: f64, delta_min: f64, delta_max: f64, flavors: Vec<i32>, format: String, alphas_q_values: Vec<f64>, alphas_vals: Vec<f64>, polarised: bool, set_type: PySetType, interpolator_type: PyInterpolatorType, error_type: String, hadron_pid: i32, phys_params: PyPhysicsParameters, ) -> Self
Constructor for PyMetaData.
Sourcepub fn has_key(&self, key: &str) -> bool
pub fn has_key(&self, key: &str) -> bool
Return True if the given LHAPDF-canonical key is present in the metadata.
Sourcepub fn get_entry(&self, key: &str) -> PyResult<String>
pub fn get_entry(&self, key: &str) -> PyResult<String>
Return the string value for an LHAPDF-canonical metadata key.
Errors
Raises KeyError if the key is not present.
Sourcepub fn keys(&self) -> Vec<String>
pub fn keys(&self) -> Vec<String>
Return a sorted list of all available LHAPDF-canonical metadata keys.
Sourcepub const fn number_sets(&self) -> u32
pub const fn number_sets(&self) -> u32
The number of sets in the grid.
Sourcepub const fn alphas_q(&self) -> &Vec<f64>
pub const fn alphas_q(&self) -> &Vec<f64>
The values of q for the running of the strong coupling constant.
Sourcepub const fn alphas_values(&self) -> &Vec<f64>
pub const fn alphas_values(&self) -> &Vec<f64>
The values of the running of the strong coupling constant.
Sourcepub const fn is_polarised(&self) -> bool
pub const fn is_polarised(&self) -> bool
Whether the grid is polarised.
Sourcepub fn interpolator_type(&self) -> PyInterpolatorType
pub fn interpolator_type(&self) -> PyInterpolatorType
The interpolation method used for the grid.
Sourcepub const fn error_type(&self) -> &String
pub const fn error_type(&self) -> &String
The type of error.
Sourcepub const fn hadron_pid(&self) -> i32
pub const fn hadron_pid(&self) -> i32
The hadron PID.